summaryrefslogtreecommitdiffstats
path: root/kpovmodeler/pmlightgroupedit.h
diff options
context:
space:
mode:
Diffstat (limited to 'kpovmodeler/pmlightgroupedit.h')
-rw-r--r--kpovmodeler/pmlightgroupedit.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/kpovmodeler/pmlightgroupedit.h b/kpovmodeler/pmlightgroupedit.h
index 8b1216fd..6a418bee 100644
--- a/kpovmodeler/pmlightgroupedit.h
+++ b/kpovmodeler/pmlightgroupedit.h
@@ -39,9 +39,9 @@ class PMLightGroupEdit : public PMSolidObjectEdit
typedef PMSolidObjectEdit Base;
public:
/**
* Creates a PMLightGroupEdit with tqparent and name
*/
- PMLightGroupEdit( TQWidget* tqparent, const char* name = 0 );
+ PMLightGroupEdit( TQWidget* parent, const char* name = 0 );
/** */
virtual void displayObject( PMObject* o );
@@ -39,9 +39,9 @@ class PMLightGroupEdit : public PMSolidObjectEdit
public:
/**
- * Creates a PMLightGroupEdit with tqparent and name
+ * Creates a PMLightGroupEdit with parent and name
*/